Skip to main contentCrate marauders
Source pub use api::*;pub use code::*;pub use languages::*;pub use project::*;pub use variation::*;
- algebra
- Marauders is a library and command line tool for injecting amd maintaining inline mutations in source code.
- api
api: Contains the library API for programmatic access.
Library API for programmatic access to Marauders functionality.- code
code: Contains the way marauders handle the code it analyzes and processes.- languages
languages: Contains the language specific details for marauders supported languages.- project
project: Contains the logic and structures for handling marauders projects.- syntax
syntax: Contains the different syntaxes for expressing mutants.- variation
variation: Contains the logic and structures for about variations.