try_set_variant_match_replace

Function try_set_variant_match_replace 

pub fn try_set_variant_match_replace(
    path: &Path,
    variant: &str,
) -> Result<Option<SetResult>, ApiError>
Tries to set a variant through a match-replace sidecar document.

This is used when the source file has already been converted to base code and mutations live in <source>.match_replace.json.

Returns:

  • Ok(Some(SetResult)) when a match-replace document was found and applied.
  • Ok(None) when no match-replace document is associated with path.